kmbasis: Compute the basis of a knowledge space

View source: R/kmbasis.R

kmbasisR Documentation

Compute the basis of a knowledge space

Description

kmbasis.matrix returns a matrix representing the basis of a knowledge space. If x is a knowledge structure or an arbitrary family of sets kmbasis returns the basis of the smallest knowledge space containing x.

kmbasis.kmsurmiserelation takes a surmise relation and returns the corresponding basis.

kmbasis.matrix returns a matrix representing the basis of a knowledge space. If x is a knowledge structure or an arbitrary family of sets kmbasis returns the basis of the smallest knowledge space containing x.

Usage

kmbasis(x)

## S3 method for class 'kmsurmisefunction'
kmbasis(x)

## S3 method for class 'kmsurmiserelation'
kmbasis(x)

## S3 method for class 'matrix'
kmbasis(x)

Arguments

x

Binary matrix representing a knowledge space

Value

Binary matrix representing the basis of the knowledge space.

Basis

Basis

Binary matrix representing the basis of the knowledge space.

See Also

Other Different representations for knowledge spaces: kmSF2basis(), kmSR2basis(), kmsurmisefunction(), kmsurmiserelation(), kmunionclosure()

Other Different representations for knowledge spaces: kmSF2basis(), kmSR2basis(), kmsurmisefunction(), kmsurmiserelation(), kmunionclosure()

Other Different representations for knowledge spaces: kmSF2basis(), kmSR2basis(), kmsurmisefunction(), kmsurmiserelation(), kmunionclosure()

Other Different representations for knowledge spaces: kmSF2basis(), kmSR2basis(), kmsurmisefunction(), kmsurmiserelation(), kmunionclosure()

Examples

kmbasis(xpl$space)

kmbasis(xpl$space)


kstMatrix documentation built on Feb. 28, 2026, 5:06 p.m.