Learn R Programming

kstMatrix (version 2.2-1)

kmbasisneighbourhood: Compute the neighbourhod of a state within a knowledge structure using its basis

Description

kmbasisneighbourhood computes the neighbourhood of a state within a knowledge structure, i.e. the family of all other states with a symmetric set difference of 1.

Usage

kmbasisneighbourhood(state, basis, include = FALSE)

Value

Matrix containing the neighbouring states, one per row

Arguments

state

Binary vector representing a knowledge state

basis

kmbasis object

include

Boolean whether the original state should be included in the result (default FALSE)

See Also

Other Fringes & learning paths: kmbasisfringe(), kmfringe(), kmgradations(), kmlearningpaths(), kmneighbourhood(), kmnneighbourhood()

Examples

Run this code
kmbasisneighbourhood(c(1,1,0,0), xpl$basis)

Run the code above in your browser using DataLab