kmiita2SR takes the result of a DAKS::iita() call and
delivers the matrix of the computed surmise relation.
kmiita2SR(ii, names = NULL, items = 0)Surmise relation matrix
The iita() function looses information on the item names and
uses consecutive numbers instead. The implications part of its
result does not give any hint on isolated items, i.e. items which#
neither have a prerequisite nor are prerequisite of any other item.
Therefore, a minimal number of items can be passed to
kmiita2SR(). If the highest item number within
implications is higher, this items parameter is ignored.
iita() result
Vector of item names (default NULL)
Minimal number of items (default 0)
Other Generating knowledge spaces:
kmgenerate()