powered by
kmunionclosure returns a matrix representing a knowledge space. Please note that it may take quite some time for computing larger knowledge spaces.
kmunionclosure
kmunionclosure(x)# S3 method for kmdata kmunionclosure(x)# S3 method for kmfamset kmunionclosure(x)# S3 method for kmstructure kmunionclosure(x)
# S3 method for kmdata kmunionclosure(x)
# S3 method for kmfamset kmunionclosure(x)
# S3 method for kmstructure kmunionclosure(x)
Binary matrix representing the corresponding knowledge space, i.e. the closure of the family under union including the empty set and the full set.
kmunionclosure implements the irredundant algorithm developed by Dowling (1993).
Binary matrix representing a family of sets
Dowling, C. E. (1993). On the irredundant construction of knowledge spaces. Journal of Mathematical Psychology, 37, 49–62.
Other Different representations for knowledge spaces: kmSF2basis(), kmSR2basis(), kmbasis(), kmsurmisefunction(), kmsurmiserelation()
kmSF2basis()
kmSR2basis()
kmbasis()
kmsurmisefunction()
kmsurmiserelation()
kmunionclosure(xpl$basis)
Run the code above in your browser using DataLab