kmbasis.matrix returns a matrix representing the basis of a
knowledge space. If x is a knowledge structure or an
arbitrary family of sets kmbasis returns the basis of
the smallest knowledge space containing x.
kmbasis.kmsurmiserelation takes a surmise relation and returns the
corresponding basis.
kmbasis.matrix returns a matrix representing the basis of a
knowledge space. If x is a knowledge structure or an
arbitrary family of sets kmbasis returns the basis of
the smallest knowledge space containing x.
kmbasis(x)# S3 method for kmsurmisefunction
kmbasis(x)
# S3 method for kmsurmiserelation
kmbasis(x)
# S3 method for matrix
kmbasis(x)
Binary matrix representing the basis of the knowledge space.
Basis
Basis
Binary matrix representing the basis of the knowledge space.
Binary matrix representing a knowledge space
Other Different representations for knowledge spaces:
kmSF2basis(),
kmSR2basis(),
kmsurmisefunction(),
kmsurmiserelation(),
kmunionclosure()
Other Different representations for knowledge spaces:
kmSF2basis(),
kmSR2basis(),
kmsurmisefunction(),
kmsurmiserelation(),
kmunionclosure()
Other Different representations for knowledge spaces:
kmSF2basis(),
kmSR2basis(),
kmsurmisefunction(),
kmsurmiserelation(),
kmunionclosure()
Other Different representations for knowledge spaces:
kmSF2basis(),
kmSR2basis(),
kmsurmisefunction(),
kmsurmiserelation(),
kmunionclosure()
kmbasis(xpl$space)
kmbasis(xpl$space)
Run the code above in your browser using DataLab